package es.aranova.mhp.base.controls;
/************************************************************
 * The MapGet example application.
 * Class KeypadButton
 * - Implements one button of the keypad.
 *
 * Niklas Hagstr�m		
 * Turku Centre for Computer Science - http://www.tucs.fi/
 * September, 2004
 * 
 ************************************************************
 */

import java.awt.*;

public class KeypadButton extends Component {

	// Constants
	private static final int KB_WIDTH = 75;
	private static final int KB_HEIGHT = 52;
	
	private int keyNumber = 0;
	private char[] subChars = null;
	private int activeSubChar = -1;
	private int subCharCount = 0;
	
	private boolean focused = false;
	
	private static Font mainCharFont = null;
	private static Font subCharFont = null;
	
	// Create KeypadButton.
	public KeypadButton(int keyNum, String keyChars) {
		setSize(KB_WIDTH,KB_HEIGHT);
		keyNumber = keyNum;
		subChars = keyChars.toCharArray();
		subCharCount = keyChars.length();
	
		mainCharFont = new Font("Tirealias",Font.PLAIN,27);
		subCharFont = new Font("Tirealias", Font.PLAIN,20);
	}
	
	public void paint(Graphics g) {
		super.paint(g);
		
		FontMetrics fm = null;
		String s = null;
		
		// If the button if focused it is painted with a white border.
		if (focused) {
			g.setColor(Color.white);
		} else {
			g.setColor(new Color(0x2a,0x2a,0x2a));
		}
		g.fillRect(0,0,this.getSize().width,this.getSize().height);
		g.setColor(Color.black);
		g.fillRect(2,2,this.getSize().width-4,this.getSize().height-4);
		

		// Draw subcharacters. FontMetrics is used for getting character
		// widths, so that the text can be centered.
		g.setFont(subCharFont);
		fm = g.getFontMetrics();
		int textWidth = fm.stringWidth(String.valueOf(subChars));
		int charX = (KB_WIDTH-textWidth)/2;
		for (int i=0;i<subCharCount;i++) {
			if (i==activeSubChar) {
				g.setColor(Color.white); 
			} else { 
				g.setColor(new Color(0x3f,0x3f,0xff));
			}
			s = String.valueOf(subChars[i]);
			g.drawString(s,charX,46);
			charX += fm.charWidth(subChars[i]);
		}
		// Draw key number.
		g.setFont(mainCharFont);
		fm = g.getFontMetrics();
		g.setColor(Color.white);
		s = String.valueOf(keyNumber);
		g.drawString(s,(KB_WIDTH-fm.stringWidth(s))/2,26);
	}

	public void press() {
		if (activeSubChar == -1) {
			focused = true;
			activeSubChar = 0;
		} else {
			activeSubChar = (activeSubChar+1) % subCharCount;
		}
		repaint();
	}
		
	public void unpress() {
		activeSubChar = -1;
		focused = false;
		repaint();
	}

	public char getChar() {
		if (subChars != null) return subChars[activeSubChar];
		return 0;
	}
}